'use strict'

var Integration = require('@segment/analytics.js-integration')
var is = require('is')

/**
 * Expose `HotJar` integration
 */

var HotJar = module.exports = Integration('HotJar')
  .option('hjid', null)
  .option('hjPlaceholderPolyfill', true)
  .tag('<script src="https://static.hotjar.com/c/hotjar-{{ hjid }}.js?sv=5">')

/**
 * Initialize HotJar
 */

HotJar.prototype.initialize = function () {
  // Make sure our metadata inputs are valid, putting out a console error and aborting if not.
  function areOptionsValid (options) {
    var validators = {
      isHjidValid: is.number(options.hjid) && !is.nan(options.hjid), // Make sure that HJID is a number (and isn't NaN)
      isPlaceholderPolyfillValid: is.bool(options.hjPlaceholderPolyfill) // Make sure we received a boolean.
    }

    for (var validator in validators) {
      if (!validators[validator]) {
        console.warn('HotJar Integration - ' + validator + ' returned false, not loading.')
        return false
      }
    }

    return true
  }

  // Convert from string to number.
  this.options.hjid = Number(this.options.hjid)
  if (!areOptionsValid(this.options)) return

  // Set needed global variables. HJSV is the snippet version, currently at `5` - https://docs.hotjar.com/docs/hotjar-tracking-code
  window.hj = window.hj || function () { (window.hj.q = window.hj.q || []).push(arguments) }
  window._hjSettings = {
    hjid: this.options.hjid,
    hjsv: 5,
    hjPlaceholderPolyfill: this.options.hjPlaceholderPolyfill
  }

  this.load()
  this.ready()
}
